==> qddb-1.42.2.tar.gz: qddb-1.42.2/acconfig.h <==

/* acconfig.h -- Custom header for GNU autoconf.
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 *
 */
/*
 *   Leave the following blank line there!!  Autoheader needs it.  
 */


/* Define to change default date format from %m/%d/%y */
#undef DEFAULT_DATE_FORMAT

/* Define to turn on diagnostic checking */
#undef DIAGNOSTIC

#undef HAVE_TIMEZONE_VAR

#undef HAVE_TM_GMTOFF

#undef HAVE_TM_TZADJ

/* Define to change default editor from /usr/bin/vi */
#undef LOCAL_DEFAULT_EDITOR

/* Define to turn on MAXIMUM_MEMORY_USAGE checking */
#undef MAXIMUM_MEMORY_USAGE

/* Define if we are using libBLT.a */
#undef USE_BLT

/* Define if you want Expect included in qddb_{tclsh, wish} */
#undef USE_EXPECT

/* Define if you want GNU malloc routines */
#undef USE_GNU_MALLOC

/* Define if you want [incr Tcl] library included in qddb_{tclsh, wish} */
#undef USE_ITCL

/* Define if you want to print GNU malloc statistics */
#undef USE_MALLOC_STATS

/* Define if you want fcntl-style record locking */
#undef USE_RECORD_LOCKING

/* Define if you want Tcl. */
#undef USE_TCL

/* Define if you want tclTCP included in qddb_{tclsh, wish} */
#undef USE_TCL_TCP

/* Define if you want TkTable included in qddb_wish */
#undef USE_TK_TABLE

/* Define if you want TclX included in qddb_{tclsh, wish} */
#undef USE_TCLX

/* Define if we are using libXpm.a */
#undef USE_XPM


/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */

==> qddb-1.43.tar.gz: qddb-1.43/acconfig.h <==

/* acconfig.h -- Custom header for GNU autoconf.
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 *
 */
/*
 *   Leave the following blank line there!!  Autoheader needs it.  
 */


/* Define to change default date format from %m/%d/%y */
#undef DEFAULT_DATE_FORMAT

/* Define to turn on diagnostic checking */
#undef DIAGNOSTIC

#undef HAVE_HYPOT

#undef HAVE_RINT

#undef HAVE_TIMEZONE_VAR

#undef HAVE_TM_GMTOFF

#undef HAVE_TM_TZADJ

/* Define if you have flock() */
#undef HAVE_FLOCK

/* Define to change default editor from /usr/bin/vi */
#undef LOCAL_DEFAULT_EDITOR

/* Define to turn on MAXIMUM_MEMORY_USAGE checking */
#undef MAXIMUM_MEMORY_USAGE

/* Define if we are using libBLT.a */
#undef USE_BLT

/* Define if you want Expect included in qddb_{tclsh, wish} */
#undef USE_EXPECT

/* Define if you want GNU malloc routines */
#undef USE_GNU_MALLOC

/* Define if you want [incr Tcl] library included in qddb_{tclsh, wish} */
#undef USE_ITCL

/* Define if you want [incr Tcl] library (V2) included in qddb_{tclsh, wish} */
#undef USE_ITCL2

/* Define if you want to print GNU malloc statistics */
#undef USE_MALLOC_STATS

/* Define if you want fcntl-style record locking */
#undef USE_RECORD_LOCKING

/* Define if you want Tcl. */
#undef USE_TCL

/* Define if you want tclTCP included in qddb_{tclsh, wish} */
#undef USE_TCL_TCP

/* Define if you want TclX included in qddb_{tclsh, wish} */
#undef USE_TCLX

/* Define if you want Tix included in qddb_{tclsh, wish} */
#undef USE_TIX

/* Define if you want Tree included in qddb_{tclsh, wish} */
#undef USE_TREE

/* Define if you want TkTable included in qddb_wish */
#undef USE_TK_TABLE

/* Define if we are using libXpm.a */
#undef USE_XPM



/* Leave that blank line there!!  Autoheader needs it.
   If you're adding to this file, keep in mind:
   The entries are in sort -df order: alphabetical, case insensitive,
   ignoring punctuation (such as underscores).  */
